@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_IMAGE_EDITOR_TOOL_H
-#define DIGIKAM_IMAGE_EDITOR_TOOL_H
+#pragma once
 
 // Qt includes
 
@@ -118,7 +117,7 @@ protected Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 // -----------------------------------------------------------------
@@ -214,9 +213,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_IMAGE_EDITOR_TOOL_H
